﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Input;
using System.Windows;
using Infragistics.Windows.DataPresenter;

namespace XamDataGridDoubleClickCommand
{
    public class XamDataPresenter
    {
        public static readonly DependencyProperty DoubleClickCommandProperty = DependencyProperty.RegisterAttached("DoubleClickCommand", typeof(ICommand), typeof(XamDataPresenter), new PropertyMetadata(null, OnDoubleClickCommandChanged));
        public static void SetDoubleClickCommand(DataPresenterBase grid, ICommand command)
        {
            grid.SetValue(DoubleClickCommandProperty, command);
        }
        public static ICommand GetDoubleClickCommand(DataPresenterBase grid)
        {
            return grid.GetValue(DoubleClickCommandProperty) as ICommand;
        }

        private static void OnDoubleClickCommandChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            DataPresenterBase presenter = (DataPresenterBase)d;

            presenter.MouseDoubleClick += (o, ea) =>
            {
                ICommand command = (ICommand)presenter.GetValue(DoubleClickCommandProperty);
                object commandParameter = presenter.GetValue(DoubleClickCommandParameterProperty);

                if (command.CanExecute(commandParameter))
                    command.Execute(commandParameter);
            };
        }

        public static readonly DependencyProperty DoubleClickCommandParameterProperty = DependencyProperty.RegisterAttached("DoubleClickCommandParameter", typeof(object), typeof(XamDataPresenter));
        public static void SetDoubleClickCommandParameter(DataPresenterBase grid, object parameter)
        {
            grid.SetValue(DoubleClickCommandParameterProperty, parameter);
        }
        public static object GetDoubleClickCommandParameter(DataPresenterBase grid)
        {
            return grid.GetValue(DoubleClickCommandParameterProperty);
        }
    }
}
